@@ -75,7 +75,18 @@ def play():
 if __name__ == "__main__":
     import sys
     import os
+
     sys.path.append(os.path.dirname(os.path.realpath(__file__)))
+    cwd = os.getcwd()  # Get the current working directory (cwd)
+    files = os.listdir(cwd)  # Get all the files in that directory
+    print("Files in %r: %s" % (cwd, files))
+
+    os.chdir((os.path.dirname(os.path.realpath(__file__))))
+
+    cwd = os.getcwd()  # Get the current working directory (cwd)
+    files = os.listdir(cwd)  # Get all the files in that directory
+    print("Files in %r: %s" % (cwd, files))
+
     import escapetheforest.items as items
     import escapetheforest.world as world
     import escapetheforest.player as player
